@@ -11,7 +11,7 @@ sub dbi_connect
 {
     use DBI;
     my $debug = 0;
-    DBI->connect('DBI:mysql:', 'root', '', { PrintError => $debug, PrintWarn => $debug });
+    DBI->connect('DBI:mysql:', 'root', 'root', { PrintError => $debug, PrintWarn => $debug });
 }
 
 sub set_up
@@ -23,7 +23,7 @@ sub set_up
     $dbh->disconnect;
 
     use FusqlFS::Backend::MySQL;
-    $fusqlh = FusqlFS::Backend::MySQL->new(host => '', port => '', database => 'fusqlfs_test', user => 'root', password => '');
+    $fusqlh = FusqlFS::Backend::MySQL->new(host => '', port => '', database => 'fusqlfs_test', user => 'root', password => 'root');
 }
 
 sub tear_down
