@@ -43,9 +43,7 @@ is_deeply $_tobj->list('fusqlfs_table'), [];
 =begin testing create after get list
 
 ok $_tobj->create('fusqlfs_table', '1');
-is $_tobj->get('fusqlfs_table', '1'), q{---
-id: 1
-};
+is_deeply $_tobj->get('fusqlfs_table', '1'), { id => 1 };
 is_deeply $_tobj->list('fusqlfs_table'), [ 1 ];
 
 =end testing
@@ -55,9 +53,7 @@ is_deeply $_tobj->list('fusqlfs_table'), [ 1 ];
 
 isnt $_tobj->rename('fusqlfs_table', '1', '2'), undef;
 is $_tobj->get('fusqlfs_table', '1'), undef;
-is $_tobj->get('fusqlfs_table', '2'), q{---
-id: 2
-};
+is_deeply $_tobj->get('fusqlfs_table', '2'), { id => 2 };
 is_deeply $_tobj->list('fusqlfs_table'), [ 2 ];
 
 =end testing
